=========
Changelog
=========

Version 0.0.4
==================
* fix beam search exception in CopyRNN

Version 0.0.3
==================

- fix github workflow push config

Version 0.0.2
==================

- fix requirement bug

Version 0.0.1
==================

- construct basic architecture of project
- implement CopyRNN (total available), CopyTransformer (required to debug)


